# Changelog

## [v0.1.0](https://github.com/kai2nenobu/keepassxc-run/compare/v0.0.3...v0.1.0) - 2024-12-25
- Add a feature to mask secrets and "--no-masking" option by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/16
- build(deps): bump astral-sh/setup-uv from 4 to 5 in the all group by @dependabot in https://github.com/kai2nenobu/keepassxc-run/pull/15
- Use pre-commit to lint and format by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/18

## [v0.0.3](https://github.com/kai2nenobu/keepassxc-run/compare/v0.0.2...v0.0.3) - 2024-12-06
- Add tests in various environments by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/8
- Enrich logging message by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/11
- Refactoring to extract secret fetcing operation into a separate class by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/12
- Enrich project information by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/13

## [v0.0.2](https://github.com/kai2nenobu/keepassxc-run/compare/v0.0.1...v0.0.2) - 2024-12-04
- log error message when git-credential-keepassxc failed by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/4
- Release a new version by using tagpr by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/5
- Add a release job by @kai2nenobu in https://github.com/kai2nenobu/keepassxc-run/pull/7

## [v0.0.1](https://github.com/kai2nenobu/keepassxc-run/commits/v0.0.1) - 2024-11-28

- Initial implementation
